==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Autenticazione scaduta</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disco occupato, impossibile smontare</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disco occupato, impossibile espellerlo ora</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Disco occupato, impossibile espellerlo ora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Disco occupato, impossibile espellerlo ora</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Il dispositivo non è stato rimosso in sicurezza</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clicca su &quot;Rimozione sicura&quot; e rimuovilo solo successivamente</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Disco occupato, impossibile espellerlo ora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Disco occupato, impossibile espellerlo ora</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Impossibile smontare il dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Il disco è stato montato dall&apos;utente &quot;%1&quot;, non puoi smontarlo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Impossibile trovare il dispositivo montato</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dischi</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Espelli tutto</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Il dispositivo è stato rimosso in sicurezza</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Accesso negato</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Non hai i permessi per accedere a questa cartella</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scansione del dispositivo in corso, interromperla?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Autenticazione scaduta</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disco occupato, impossibile smontare</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disco occupato, impossibile espellerlo ora</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Disco occupato, impossibile espellerlo ora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Disco occupato, impossibile espellerlo ora</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Il dispositivo non è stato rimosso in sicurezza</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clicca su &quot;Rimozione sicura&quot; e rimuovilo solo successivamente</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Impossibile smontare il dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Il disco è stato montato dall&apos;utente &quot;%1&quot;, non puoi smontarlo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Impossibile trovare il dispositivo montato</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dischi</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Espelli tutto</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Il dispositivo è stato rimosso in sicurezza</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Accesso negato</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Non hai i permessi per accedere a questa cartella</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scansione del dispositivo in corso, interromperla?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Stop</translation>
    </message>
</context>
</TS>
